﻿using System;
using System.Collections.Generic;
using System.ComponentModel.Composition;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using VisualComponents.Create3D;
using VisualComponents.UX.Shared;

namespace HelloWorldDemo
{
    [Export(typeof(IDockableScreen))]
    class HelloWorldPanelViewModel : DockableScreen
    {
        [Import]
        IApplication _application = null;

        [Import]
        IRenderService _renderService = null;


        public HelloWorldPanelViewModel()
        {
            this.DisplayName = "Hello Panel";
            this.IsPinned = true;
            this.PaneLocation = DesiredPaneLocation.DockedRight;
        }

        protected override void OnActivate()
        {
            _application.World.ComponentAdded += World_ComponentAdded;
            _application.World.ComponentRemoving += World_ComponentRemoving;
        }

        protected override void OnDeactivate(bool close)
        {
            base.OnDeactivate(close);
            _application.World.ComponentAdded -= World_ComponentAdded;
            _application.World.ComponentRemoving -= World_ComponentRemoving;
        }

        void World_ComponentAdded(object sender, ComponentAddedEventArgs e)
        {
            CanCreateBox = false;
        }

        void World_ComponentRemoving(object sender, ComponentRemovingEventArgs e)
        {
            CanCreateBox = _application.World.Components.Count == 1;
        }

        public void CreateBox()
        {
            ISimComponent component = _application.World.CreateComponent("MyBox");
            component.RootNode.RootFeature.CreateFeature<IBlockFeature>();
            component.Rebuild();

            _renderService.RequestRender();
        }

        private bool _canCreateBox = true;
        public bool CanCreateBox
        {
            get { return _canCreateBox; }
            private set
            {
                _canCreateBox = value;
                NotifyOfPropertyChange(() => CanCreateBox);
            }
        }
    }
}
